@@ -287,7 +287,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
             except: pass
 
     myname = args["n"]
-    N = str(len(os.path.split(myname)))
+    N = len(os.path.split(myname))
 
     sources = [a for i,a in sorted(sources)]
     targets = [a for i,a in sorted(targets)]
